#ifndef _WIMLIB_XML_WINDOWS_H
#define _WIMLIB_XML_WINDOWS_H

#include "wimlib/types.h"

int
set_windows_specific_info(WIMStruct *wim);

#endif /* _WIMLIB_XML_WINDOWS_H */
